pub fn parse_find_statement(
ctx: &mut ParseContext<'_>,
find_statement: Node<'_>,
) -> Result<BTreeMap<Name, DomainPtr>, FatalParseError>Expand description
Parse a find statement into a map of decision variable names to their domains.
pub fn parse_find_statement(
ctx: &mut ParseContext<'_>,
find_statement: Node<'_>,
) -> Result<BTreeMap<Name, DomainPtr>, FatalParseError>Parse a find statement into a map of decision variable names to their domains.